@@ -7,7 +7,7 @@
 # Simple calculator library
 
 
-class ModelUtils(object):
+class ModelUtils:
 
     def __init__(self):
 
